@@ -16,12 +16,13 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
 #include "arch.h"
 #include "archiveformatinfo.h"
+#include "settings.h"
 
 #include <klocale.h>
 #include <kdebug.h>
@@ -51,6 +52,7 @@ void ArchiveFormatInfo::buildFormatInfos()
   addFormatInfo( TAR_FORMAT, "application/x-tzo", ".tar.lzo" );
   addFormatInfo( TAR_FORMAT, "application/x-tarz", ".tar.z" );
   addFormatInfo( TAR_FORMAT, "application/x-tbz", ".tar.bz2" );
+  addFormatInfo( TAR_FORMAT, "application/x-tbz2", ".tar.bz2" );
   // x-tar as the last one to get its comment for all the others, too
   addFormatInfo( TAR_FORMAT, "application/x-tar", ".tar" );
 
@@ -58,7 +60,7 @@ void ArchiveFormatInfo::buildFormatInfos()
 
   addFormatInfo( ZIP_FORMAT, "application/x-jar", ".jar" );
   addFormatInfo( ZIP_FORMAT, "application/x-zip", ".zip" );
-
+  addFormatInfo( ZIP_FORMAT, "application/x-zip-compressed", ".zip" );
 
   addFormatInfo( COMPRESSED_FORMAT, "application/x-gzip", ".gz" );
   addFormatInfo( COMPRESSED_FORMAT, "application/x-bzip", ".bz" );
@@ -70,11 +72,15 @@ void ArchiveFormatInfo::buildFormatInfos()
   addFormatInfo( ZOO_FORMAT, "application/x-zoo", ".zoo" );
 
   addFormatInfo( RAR_FORMAT, "application/x-rar", ".rar" );
-  
+  addFormatInfo( RAR_FORMAT, "application/x-rar-compressed", ".rar" );
+
   addFormatInfo( AA_FORMAT, "application/x-deb", ".deb" );
   addFormatInfo( AA_FORMAT, "application/x-archive",".a" );
-  
+
   addFormatInfo( SEVENZIP_FORMAT, "application/x-7z", ".7z" );
+
+  if ( ArkSettings::aceSupport() )
+    addFormatInfo( ACE_FORMAT, "application/x-ace", ".ace" );
 }
 
 void ArchiveFormatInfo::addFormatInfo( ArchType type, QString mime, QString stdExt )
