@@ -21,7 +21,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -126,7 +126,7 @@ ArkApplication::newInstance()
     {
         if ( args->count() == 2 )
         {
-            ArkTopLevelWindow *arkWin = new ArkTopLevelWindow();
+            MainWindow *arkWin = new MainWindow();
 
             arkWin->extractTo( args->url( 0 ), args->url( 1 ), args->isSet( "guess-name" ) );
             return 0;
@@ -151,7 +151,7 @@ ArkApplication::newInstance()
             for ( int c = 0; c < args->count()-1 ; c++ )
                 URLList.append( args->url( c ) );
 
-            ArkTopLevelWindow *arkWin = new ArkTopLevelWindow();
+            MainWindow *arkWin = new MainWindow();
 
             arkWin->addToArchive( URLList, args->cwd(), args->url( args->count()-1 ) );
             return 0;
@@ -174,7 +174,7 @@ ArkApplication::newInstance()
         for ( int c = 1; c < args->count(); c++ )
             URLList.append( args->url( c ) );
 
-        ArkTopLevelWindow *arkWin = new ArkTopLevelWindow();
+        MainWindow *arkWin = new MainWindow();
 
         arkWin->addToArchive( URLList, args->cwd(), archiveName, !oneFile );
         return 0;
@@ -194,7 +194,7 @@ ArkApplication::newInstance()
             for ( int c = 0; c < args->count() ; c++ )
                 URLList.append( args->url( c ) );
 
-            ArkTopLevelWindow *arkWin = new ArkTopLevelWindow();
+            MainWindow *arkWin = new MainWindow();
 
             arkWin->addToArchive( URLList, args->cwd() );
             return 0;
@@ -205,13 +205,14 @@ ArkApplication::newInstance()
     int i = 0;
     KURL url;
     bool doAutoExtract = args->isSet("extract");
+    bool tempFile = KCmdLineArgs::isTempFileSet();
     do
     {
         if (args->count() > 0)
         {
             url = args->url(i);
         }
-        ArkTopLevelWindow *arkWin = new ArkTopLevelWindow();
+        MainWindow *arkWin = new MainWindow();
         arkWin->show();
         if(doAutoExtract)
         {
@@ -219,7 +220,7 @@ ArkApplication::newInstance()
         }
         if (!url.isEmpty())
         {
-            arkWin->openURL(url);
+            arkWin->openURL(url, tempFile);
         }
 
         ++i;
@@ -231,7 +232,7 @@ ArkApplication::newInstance()
 
 
 void
-ArkApplication::addOpenArk(const KURL & _arkname, ArkTopLevelWindow *_ptr)
+ArkApplication::addOpenArk(const KURL & _arkname, MainWindow *_ptr)
 {
     QString realName;
     if( _arkname.isLocalFile() )
@@ -263,7 +264,7 @@ void
 ArkApplication::raiseArk(const KURL & _arkname)
 {
     kdDebug( 1601 ) << "ArkApplication::raiseArk " << endl;
-    ArkTopLevelWindow *window;
+    MainWindow *window;
     QString realName;
     if( _arkname.isLocalFile() )
         realName = resolveFilename(_arkname.path());  // follow symlink
