@@ -1,5 +1,5 @@
 /*
-    $Id: stats.h 442239 2005-08-02 00:32:37Z kniederk $
+    $Id: stats.h 490596 2005-12-22 13:05:45Z scripty $
 
     KCalc, a scientific calculator for the X window system using the
     Qt widget libraries, available at no cost at http://www.troll.no
@@ -19,7 +19,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
