@@ -17,7 +17,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
     */
 
@@ -103,7 +103,7 @@ public:
 
     /// List of all windows
     static QPtrList<TopLevel> *windowList;
-    QPopupMenu *right_mouse_button;
+    //QPopupMenu *right_mouse_button;
 
     bool queryExit( void );
     bool queryClose( void );
