@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -27,6 +27,7 @@
 
 #include <kglobalsettings.h>
 #include <klocale.h>
+#include <kstdguiitem.h>
 
 #include "chartabledialog.h"
 
@@ -34,7 +35,7 @@
 CCharTableDialog::CCharTableDialog( QWidget *parent, const char *name,
 				    bool modal )
   :KDialogBase( Plain, i18n("Character Table"), Help|User1|Cancel, User1,
-		parent, name, modal, true, i18n("&Insert") )
+		parent, name, modal, true, KStdGuiItem::insert())
 {
   updateGeometry();
   setHelp( "khexedit/khexedit.html", QString::null );
