@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -281,7 +281,7 @@ void CHexEditorWidget::readConfiguration( KConfig &config )
   SDisplayFont &font = mDisplayState.font;
   config.setGroup( "Display Font" );
   font.useSystemFont = config.readBoolEntry(
-    "UseSystemFont", font.useSystemFont );
+    "UseSystemFont", true );
   font.localFont = config.readFontEntry(
     "LocalFont", &font.localFont );
   font.nonPrintChar = config.readNumEntry(
@@ -651,7 +651,7 @@ void CHexEditorWidget::open()
   if( !createBuffer() )
     return;
 
-  int errCode = readURL( url, false );
+  int errCode = readURL( file, false );
   if( errCode != Err_Success )
   {
     emit errorLoadFile( url );
@@ -777,7 +777,7 @@ void CHexEditorWidget::insertFile( void )
 
   if( !file.isLocalFile() )
   {
-    KMessageBox::sorry( 0L, i18n( "Only local files are currently supported." ) );
+    KMessageBox::sorry( this, i18n( "Only local files are currently supported." ) );
     return;
   }
 
@@ -840,7 +840,6 @@ bool CHexEditorWidget::closeAll( void )
       {
 	return( false );
       }
-      break;
     }
 
     //
@@ -869,7 +868,7 @@ bool CHexEditorWidget::querySave( void )
   QString msg = i18n(""
     "The current document has been modified.\n"
     "Do you want to save it?" );
-  int reply = KMessageBox::warningYesNoCancel( topLevelWidget(), msg );
+  int reply = KMessageBox::warningYesNoCancel( topLevelWidget(), msg, QString::null, KStdGuiItem::save(), KStdGuiItem::discard() );
   if( reply == KMessageBox::Yes )
   {
     return( save() );
@@ -936,7 +935,7 @@ bool CHexEditorWidget::save( void )
        "If you save now, those changes will be lost.\n"
        "Proceed?" );
       int reply = KMessageBox::warningYesNoCancel( topLevelWidget(), msg,
-						   i18n("Save") );
+						   i18n("Save"), KStdGuiItem::save(), KStdGuiItem::discard() );
       if( reply == KMessageBox::No || reply == KMessageBox::Cancel )
       {
 	return( reply == KMessageBox::No ? true : false );
@@ -987,9 +986,9 @@ bool CHexEditorWidget::saveAs( void )
 	QString msg = i18n(""
           "A document with this name already exists.\n"
           "Do you want to overwrite it?" );
-	int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
-					       i18n("Save As") );
-	if( reply == KMessageBox::Yes )
+	int reply = KMessageBox::warningContinueCancel( topLevelWidget(), msg,
+					       i18n("Save As"), i18n("Overwrite") );
+	if( reply == KMessageBox::Continue )
 	  break;
       }
       else
@@ -1031,15 +1030,16 @@ void CHexEditorWidget::reload( void )
     QString msg;
     if( modifiedByAlien( mHexView->url() ) == true )
     {
-      msg += i18n("The current document has changed on the disk and "
-                  "also contains unsaved modifications.\n" );
+      msg = i18n( "The current document has changed on the disk and "
+                  "also contains unsaved modifications.\n"
+                  "If you reload now, the modifications will be lost." );
     }
     else
     {
-      msg += i18n( "The current document contains unsaved modifications.\n" );
+      msg = i18n( "The current document contains unsaved modifications.\n"
+                   "If you reload now, the modifications will be lost." );
     }
 
-    msg += i18n("If you reload now, the modifications will be lost.");
     int reply = KMessageBox::warningContinueCancel(topLevelWidget(),msg,i18n("Reload"), i18n("&Reload"));
     if( reply != KMessageBox::Continue )
     {
@@ -1149,8 +1149,8 @@ bool CHexEditorWidget::confirmPrintPageNumber( CHexPrinter &printer )
 	"Proceed?</qt>",
 	numPageSelected );
       int reply = KMessageBox::warningYesNo( topLevelWidget(), msg,
-					     i18n("Print") );
-      if( reply != KMessageBox::Yes )
+					     i18n("Print"), KStdGuiItem::print(), KStdGuiItem::cancel() );
+      if( reply != KMessageBox::Continue )
       {
 	return( false );
       }
@@ -1412,8 +1412,8 @@ void CHexEditorWidget::removeAllBookmark( void )
     QString msg = i18n(""
       "Deleted bookmarks can not be restored.\n"
       "Proceed?" );
-    int reply = KMessageBox::warningYesNo( topLevelWidget(), msg );
-    if( reply != KMessageBox::Yes )
+    int reply = KMessageBox::warningContinueCancel( topLevelWidget(), msg );
+    if( reply != KMessageBox::Continue )
     {
       return;
     }
@@ -1580,7 +1580,7 @@ bool CHexEditorWidget::askWrap( bool fwd, const QString &header )
       "Continue from the end?" );
   }
 
-  int reply = KMessageBox::questionYesNo( topLevelWidget(), msg, header );
+  int reply = KMessageBox::questionYesNo( topLevelWidget(), msg, header, KStdGuiItem::cont(), KStdGuiItem::cancel() );
   return( reply == KMessageBox::Yes ? true : false );
 }
 
@@ -1769,8 +1769,9 @@ void CHexEditorWidget::replaceResult( SSearchControl &sc )
   }
   else
   {
-    QString msg( i18n( "Operation complete.\n\n" ) );
-    msg += i18n( "One replacement was made.","%n replacements were made.",sc.numReplace);
+    const QString msg = i18n(
+      "<qt>Operation complete.<br><br>One replacement was made.</qt>",
+      "<qt>Operation complete.<br><br>%n replacements were made.</qt>", sc.numReplace );
     KMessageBox::information( topLevelWidget(), msg, i18n("Find & Replace"));
   }
 }
@@ -1962,38 +1963,35 @@ void CHexEditorWidget::favorites( void )
 }
 
 
-int CHexEditorWidget::readURL( const QString &url, bool insert )
+int CHexEditorWidget::readURL( const KURL &url, bool insert )
 {
   //
   // 1) Make sure there is data in the url
   //
-  if( url.isEmpty() == true )
-  {
+  if( url.isEmpty() )
     return( Err_EmptyArgument );
-  }
 
   //
-  // 2) Verify that the url is valid URL string.
+  // 2) Verify that the url is valid URL string. If not, try to repair it.
   // This will work if the url contains a name of a file in the
   // current directory.
   //
-  KURL kurl( url );
-  if( !kurl.isValid() )
+  if( !url.isValid() )
   {
-    QString msg = i18n("Malformed URL\n%1").arg( kurl.url() );
+    QString msg = i18n("Malformed URL\n%1").arg( url.url() );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read URL") );
     return( Err_IllegalArgument );
   }
 
   //
-  // 3) Load the file. Since this is an url we check if this is a local
-  // or a "remote" file. The local file can be opened as a regular file.
+  // 3) Load the file.
   //
   QString tmpfile;
-  if ( !KIO::NetAccess::download( kurl, tmpfile, this ) )
+  if ( !KIO::NetAccess::download( url, tmpfile, this ) )
     return Err_ReadFailed;
 
-  bool success = readFile( tmpfile, kurl.url(), insert );
+  bool success = readFile( tmpfile, url.url(), insert );
+
   KIO::NetAccess::removeTempFile( tmpfile );
 
   return( success == true ? Err_Success : Err_ReadFailed );
@@ -2014,7 +2012,7 @@ void CHexEditorWidget::writeURL( QString &url )
     if( !KIO::NetAccess::upload(tf.name(),url,this) )
     {
       mHexView->setModified( modified );
-      QString msg = i18n("You do not have write permission."); // not precise, it simply failed for whatever reason
+      QString msg = i18n("Could not save remote file.");
       KMessageBox::sorry( topLevelWidget(), msg, i18n("Write Failure") );
     }
   }
@@ -2051,24 +2049,21 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
   QFileInfo info( diskPath );
   if( info.exists() == false )
   {
-    QString msg = i18n("The specified file does not exist.");
-    msg += "\n" + diskPath;
+    const QString msg = i18n("The specified file does not exist.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
 
   if( info.isDir() == true )
   {
-    QString msg = i18n("You have specified a folder.");
-    msg += "\n" + diskPath;
+    const QString msg = i18n("You have specified a folder.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
 
   if( info.isReadable() == false )
   {
-    QString msg = i18n("You do not have read permission to this file.");
-    msg += "\n" + diskPath;
+    const QString msg = i18n("You do not have read permission to this file.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
@@ -2076,8 +2071,7 @@ bool CHexEditorWidget::readFile( const QString &diskPath, const QString &url,
   QFile file( diskPath );
   if( file.open( IO_ReadOnly | IO_Raw ) == false )
   {
-    QString msg = i18n("An error occurred while trying to open the file.");
-    msg += "\n" + diskPath;
+    const QString msg = i18n("An error occurred while trying to open the file.\n%1").arg( diskPath );
     KMessageBox::sorry( topLevelWidget(), msg, i18n("Read") );
     return( false );
   }
@@ -2383,8 +2377,9 @@ int CHexEditorWidget::progressParse( const SProgressData &pd )
     break;
 
     case pg_write:
-      msg  = i18n("Do you really want to cancel writing?\n");
-      msg += i18n("WARNING: Canceling can corrupt your data on disk");
+      header = i18n("Write");
+      msg  = i18n("Do you really want to cancel writing?\n"
+                  "WARNING: Canceling can corrupt your data on disk");
     break;
 
     case pg_insert:
@@ -2423,7 +2418,7 @@ int CHexEditorWidget::progressParse( const SProgressData &pd )
 
   }
 
-  int reply = KMessageBox::warningYesNo( topLevelWidget(), msg, header );
+  int reply = KMessageBox::warningYesNo( topLevelWidget(), msg, header, KStdGuiItem::cancel(), KStdGuiItem::cont() );
   mProgressStop = false;
   return( reply == KMessageBox::Yes ? Err_Stop : Err_Success );
 }
