@@ -17,15 +17,15 @@
 #ifndef KHEXEDIT_HELPER
 #define KHEXEDIT_HELPER
 
-// c specific
-#include <ctype.h>
 // qt specific
 #include <qcolor.h>
+// lib specific
+#include <khechar.h>
 
 // temporary solution until syntax highlighting is implemented
-static inline QColor colorForByte( const char Byte )
+static inline QColor colorForChar( const KHE::KHEChar Byte )
 {
-  return ispunct(Byte) ? Qt::red: isprint(Byte) ? Qt::black : Qt::blue;
+  return Byte.isUndefined() ? Qt::yellow : Byte.isPunct() ? Qt::red : Byte.isPrint() ? Qt::black : Qt::blue;
 }
 
 #endif
