@@ -67,27 +67,27 @@ class KHEXEDIT_EXPORT KBytesEdit : public KHexEdit
     /** creates a new widget to view/edit data
       * @param D pointer to memory
       * @param S size of used memory
-      * @param RS real size of the memory
-      * @param KM keep the memory on resize (RS is then the maximum size)
+      * @param RS_ real size of the memory
+      * @param KM keep the memory on resize (RS_ is then the maximum size)
       * @param Parent parent widget
       * @param Name name for this widget
       * @param F flags
       */
-    KBytesEdit( char *D, int DS, int RS, bool KM, QWidget *Parent = 0, const char *Name = 0, WFlags F = 0 );
+    KBytesEdit( char *D, int DS_, int RS_, bool KM, QWidget *Parent = 0, const char *Name = 0, WFlags F = 0 );
     /** hands over to the editor a new byte array.
       * If there exists an old one and autodelete is set the old one gets deleted.
       * @param D pointer to memory
       * @param S size of used memory
-      * @param RS real size of the memory
-      * @param KM keep the memory on resize (RS is the maximum size)
+      * @param RS_ real size of the memory
+      * @param KM keep the memory on resize (RS_ is the maximum size)
       */
-    KBytesEdit( char *D, int DS, QWidget *Parent = 0, const char *Name = 0, WFlags F = 0 );
+    KBytesEdit( char *D, int DS_, QWidget *Parent = 0, const char *Name = 0, WFlags F = 0 );
     /** hands over to the editor a new byte array.
       * If there exists an old one and autodelete is set the old one gets deleted.
       * @param D pointer to memory
       * @param S size of used memory
-      * @param RS real size of the memory
-      * @param KM keep the memory on resize (RS is the maximum size)
+      * @param RS_ real size of the memory
+      * @param KM keep the memory on resize (RS_ is the maximum size)
       */
     KBytesEdit( QWidget *Parent = 0, const char *Name = 0, WFlags F = 0 );
     virtual ~KBytesEdit();
@@ -116,10 +116,10 @@ class KHEXEDIT_EXPORT KBytesEdit : public KHexEdit
       * If there exists an old one and autodelete is set the old one gets deleted.
       * @param D pointer to memory
       * @param S size of used memory
-      * @param RS real size of the memory
-      * @param KM keep the memory on resize (RS is the maximum size)
+      * @param RS_ real size of the memory
+      * @param KM keep the memory on resize (RS_ is the maximum size)
       */
-    void setData( char *D, int S, int RS = -1, bool KM = true );
+    void setData( char *D, int S, int RS_ = -1, bool KM = true );
 
     /** sets whether the given array should be handled read only or not */
     virtual void setReadOnly( bool RO = true );
