@@ -14,12 +14,14 @@
  *                                                                         *
  ***************************************************************************/
 
- 
+
 #ifndef KHE_KDATABUFFER_H
 #define KHE_KDATABUFFER_H
 
 
+// lib specific
 #include "ksection.h"
+#include "khexedit_export.h"
 
 namespace KHE
 {
@@ -60,25 +62,23 @@ char KDataBufferIterator::next()
   *@author Friedrich W. H. Kossebau
   */
 
-class KDataBuffer
+class KHEXEDIT_EXPORT KDataBuffer
 {
   friend class KDataBufferIterator;
 
-  public:
-    enum KWordCharType { Any, Printable, Readable };
 
   protected:
     KDataBuffer();
   public:
     virtual ~KDataBuffer();
 
-    
+
   public: // data access API
-    /** locates working range 
-      * The idea behind is to tell buffer which range will be requested in the following time, 
+    /** locates working range
+      * The idea behind is to tell buffer which range will be requested in the following time,
       * so that e.g. the corresponding pages will be loaded in advance
       * TODO: do we really need this? Where will this lead to real enhancements?
-      * @param Range  
+      * @param Range
       * @return @c true if successfull, @c false otherwise
       */
     virtual bool prepareRange( KSection Range ) const = 0;
@@ -96,33 +96,33 @@ class KDataBuffer
     virtual const char *dataSet( KSection Section ) const = 0;
     /** convenience function, same as above */
     const char *dataSet( int Offset, int Length ) const;
-    
+
     /** requests a single byte
       * if the offset is not valid the behaviout is undefined
       * @param Offset offset of the datum requested
       */
-    virtual char datum( int Offset ) const = 0;
-    
-    /** 
-      * @return the size of the data 
+    virtual char datum( unsigned int Offset ) const = 0;
+
+    /**
+      * @return the size of the data
       */
     virtual int size() const = 0;
 
-    
+
   public: // state read API
-    /** 
-      * @return @c true if the buffer can only be read, @c false if writing is allowed 
+    /**
+      * @return @c true if the buffer can only be read, @c false if writing is allowed
       */
     virtual bool isReadOnly() const;
-    /**      
+    /**
       * @return @c true if the buffer has been modified, @c false otherwise
       */
     virtual bool isModified() const = 0;
 
-    
+
   public: // modification API
-    /** inserts bytes copied from the given source at Position. 
-      * The original data beginnung at the position is moved 
+    /** inserts bytes copied from the given source at Position.
+      * The original data beginnung at the position is moved
       * with the buffer enlarged as needed
       * If the buffer is readOnly this is a noop and returns 0.
       * @param Pos
@@ -131,27 +131,28 @@ class KDataBuffer
       * @return length of inserted data
       */
     virtual int insert( int Pos, const char* Source, int SourceLength );
-    
+
     /** removes beginning with position as much as possible
-      * @param Section 
+      * @param Section
       * @return length of removed data
       */
     virtual int remove( KSection Section );
     /** convenience function, behaves as above */
     int remove( int Pos, int Length );
-    
+
     /** replaces as much as possible
       * @param DestSection
-      * @param Source 
+      * @param Source
       * @param SourceLength
       * @return length of replacced data
       */
-    virtual int replace( KSection DestSection, const char* Source, int SourceLength ) = 0;
+    virtual unsigned int replace( KSection DestSection, const char* Source, unsigned int SourceLength ) = 0;
     /** convenience function, behaves as above */
-    int replace( int Pos, int RemoveLength, const char* Source, int SourceLength );
-    
+    unsigned int replace( unsigned int Pos, unsigned int RemoveLength,
+                          const char* Source, unsigned int SourceLength );
+
     /** moves a part of the data to a new position, while floating the other data around
-      * when moving to a higher place the lentzh of the block must be taken into account
+      * when moving to a higher place the length of the block must be taken into account
       * if the new positions extend beyond the buffers end the section is moved to the end.
       * @param DesPos position of the data where the section should be moved behind
       * @param SourceSection data section to be moved
@@ -159,104 +160,39 @@ class KDataBuffer
       */
     virtual int move( int DestPos, KSection SourceSection ) = 0;
 
-    /** sets the modified flag for the buffer 
-      * @param M 
+    /**
+     * fills the buffer with the FillChar. If the buffer is to small it will be extended as much as possible.
+     * @param FillChar char to use
+     * @param Length number of chars to fill. If Length is -1, the current buffer length is used.
+     * @param Pos position where the filling starts
+     * @return number of filled characters
+     */
+    virtual int fill( const char FillChar, int Length = -1, unsigned int Pos = 0 ) = 0;
+
+    /** sets a single byte
+     * if the offset is not valid the behaviour is undefined
+     * @param Offset offset of the datum requested
+     * @param Char new byte value
+     */
+    virtual void setDatum( unsigned int Offset, const char Char ) = 0;
+
+    /** sets the modified flag for the buffer
+      * @param M
       */
     virtual void setModified( bool M ) = 0;
 
 
   public: // service functions
-    /** copies the data of the section into a given array Dest. If the section extends the buffers range 
+    /** copies the data of the section into a given array Dest. If the section extends the buffers range
       * the section is limited to the buffer's end. If the section is invalid the behaviour is undefined.
       * @param Dest pointer to a char array large enough to hold the copied section
       * @param Source
-      * @return number of copied bytes 
+      * @return number of copied bytes
       */
     virtual int copyTo( char* Dest, KSection Source ) const;
     /** convenience function, behaves as above */
     int copyTo( char* Dest, int Pos, int n ) const;
 
-    
-  public: // word API
-    /** searches for the start of the word including the given index.
-      * if no other nonwordchar preceds this is 0;
-      * If the byte at the given Index is already a nonword char the given index is returned.
-      * @param Index index to start with
-      * @param CharType
-      * @return index of the first char of the current word or the given index if there is none
-      */
-    virtual int indexOfWordStart( int Index, KWordCharType CharType = Readable ) const;
-    virtual int indexOfLeftWordSelect( int Index, KWordCharType CharType = Readable ) const;
-    /** searches for the end of the word including the given index.
-      * If the byte at the given Index is already a nonword char the given index is returned.
-      * if no other nonwordchar follows, that of the last byte;
-      * @param Index index to start with
-      * @param CharType
-      * @return index of the last char of the current word or the given index if there is none
-      */
-    virtual int indexOfWordEnd( int Index, KWordCharType CharType = Readable ) const;
-    /** searches for the first char after the end of the word including the given index.
-      * If the byte at the given Index is already a nonword char the given index is returned.
-      * if no other nonwordchar follows that of behind the last byte;
-      * @param Index index to start with
-      * @param CharType
-      * @return index of the first char after the current word or the given index if there is none
-      */
-    virtual int indexOfRightWordSelect( int Index, KWordCharType CharType = Readable ) const;
-    /** searches for the first char after the end of the word including the given index.
-      * If the byte at the given Index is already a nonword char the given index is returned.
-      * if no other nonwordchar follows that of behind the last byte;
-      * @param Index index to start with
-      * @param CharType
-      * @return index of the first char after the current word or the given index if there is none
-      */
-//    virtual int indexOfBehindLeftWordEnd( int Index, KWordCharType CharType = Readable ) const;
-    /** searches for the first char after the end of the word including the given index.
-      * If the byte at the given Index is already a nonword char the given index is returned.
-      * if no other nonwordchar follows that of behind the last byte;
-      * @param Index index to start with
-      * @param CharType
-      * @return index of the first char after the current word or the given index if there is none
-      */
-//    virtual int indexOfBehindRightWordEnd( int Index, KWordCharType CharType = Readable ) const;
-    /** searches the start of the next previous word that does not include the given index,
-      * if no further word is found 0 is returned.
-      * if the index is out of range the behaviour is undefined.
-      * @param Index
-      * @param CharType
-      * @return index of the next previous word start or 0
-      */
-    virtual int indexOfPreviousWordStart( int Index, KWordCharType CharType = Readable ) const;
-    /** searches for the start of the next word not including the given index.
-      * if there isn't a next word the index behind end is returned
-      * @param Index
-      * @param CharType
-      * @return index of the start of the next word or behind end
-      */
-    virtual int indexOfNextWordStart( int Index, KWordCharType CharType = Readable ) const;
-    /** searches for the start of the next word not including the given index.
-      * if there isn't a next word the index of the end is returned
-      * @param Index index to start with
-      * @param CharType
-      * @return index of the last nonword char before the next word or the last index
-      */
-    virtual int indexOfBeforeNextWordStart( int Index, KWordCharType CharType = Readable ) const;
-
-    /** if Index is out of range the behaviour is undefined
-      * @param Index
-      * @param CharType 
-      * @return @c true if the byte at position i is a char of type CharType 
-      */
-    bool isWordChar( int Index, KWordCharType CharType = Readable ) const;
-
-    /** returns the section with a word around index.
-      * if there is no word the section is empty
-      * @param Index     
-      * @param CharType 
-      * @return the section with a word around index.
-      */
-    virtual KSection wordSection( int Index, KWordCharType CharType = Readable  ) const;
-
 
   public: // finding API
     /** searches beginning with byte at Pos.
@@ -271,7 +207,7 @@ class KDataBuffer
       * If the end of the section is lower then the start the search continues at the start???
       * @param 
       * @param Length length of search string
-      * @param Section section within the keydata is to be found 
+      * @param Section section within the keydata is to be found
       * @return index of the first occurence or -1
       */
     virtual int find( const char*KeyData, int Length, KSection Section ) const = 0;
@@ -299,12 +235,12 @@ inline const char *KDataBuffer::dataSet( int Offset, int Length ) const
 inline int KDataBuffer::remove( int Pos, int Length )
 { return remove( KSection(Pos,Pos+Length-1) ); }
 
-inline int KDataBuffer::replace( int Pos, int RemoveLength, const char* D, int InputLength )
+inline unsigned int KDataBuffer::replace( unsigned int Pos, unsigned int RemoveLength,
+                                 const char* D, unsigned int InputLength )
 { return replace( KSection(Pos,Pos+RemoveLength-1), D, InputLength ); }
 
 inline bool KDataBuffer::isReadOnly() const { return false; }
 
-
 }
 
 #endif
