@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -29,6 +29,7 @@
 #include <qlabel.h>
 #include <qradiobutton.h>
 #include <qspinbox.h>
+#include <qwhatsthis.h>
 
 #include <kcolordialog.h>
 #include <kcolordrag.h>
@@ -338,23 +339,23 @@ void COptionDialog::setupColorPage( void )
   topLayout->addWidget( hline );
 
   QStringList modeList;
-  modeList.append( i18n("First, third ... line background") );
-  modeList.append( i18n("Second, fourth ... line background") );
-  modeList.append( i18n("Offset background") );
-  modeList.append( i18n("Inactive background") );
-  modeList.append( i18n("Even column text") );
-  modeList.append( i18n("Odd column text") );
-  modeList.append( i18n("Non printable text") );
-  modeList.append( i18n("Offset text") );
-  modeList.append( i18n("Secondary text") );
-  modeList.append( i18n("Marked background") );
-  modeList.append( i18n("Marked text") );
-  modeList.append( i18n("Cursor background") );
-  modeList.append( i18n("Cursor text (block shape)") );
-  modeList.append( i18n("Bookmark background") );
-  modeList.append( i18n("Bookmark text") );
+  modeList.append( i18n("First, Third ... Line Background") );
+  modeList.append( i18n("Second, Fourth ... Line Background") );
+  modeList.append( i18n("Offset Background") );
+  modeList.append( i18n("Inactive Background") );
+  modeList.append( i18n("Even Column Text") );
+  modeList.append( i18n("Odd Column Text") );
+  modeList.append( i18n("Non Printable Text") );
+  modeList.append( i18n("Offset Text") );
+  modeList.append( i18n("Secondary Text") );
+  modeList.append( i18n("Marked Background") );
+  modeList.append( i18n("Marked Text") );
+  modeList.append( i18n("Cursor Background") );
+  modeList.append( i18n("Cursor Text (block shape)") );
+  modeList.append( i18n("Bookmark Background") );
+  modeList.append( i18n("Bookmark Text") );
   modeList.append( i18n("Separator") );
-  modeList.append( i18n("Grid lines") );
+  modeList.append( i18n("Grid Lines") );
 
   mColor.colorList = new CColorListBox( page );
   topLayout->addWidget( mColor.colorList, 10 );
@@ -450,6 +451,10 @@ void COptionDialog::setupFilePage( void )
 
   text = i18n("&Jump to previous cursor position on startup");
   mFile.gotoOffsetCheck = new QCheckBox( text, page );
+  // ### TODO: this is currently not available.
+  mFile.gotoOffsetCheck->setChecked( false );
+  mFile.gotoOffsetCheck->setEnabled( false );
+  // ### END
   topLayout->addWidget( mFile.gotoOffsetCheck, 0, AlignLeft );
   connect( mFile.gotoOffsetCheck, SIGNAL(toggled(bool)),
     this, SLOT( slotChanged()));
@@ -483,12 +488,21 @@ void COptionDialog::setupFilePage( void )
   text = i18n("Don't &save \"Recent\" document list on exit");
   mFile.discardRecentCheck = new QCheckBox( text, page );
   topLayout->addWidget( mFile.discardRecentCheck, 0, AlignLeft );
+  QWhatsThis::add( mFile.discardRecentCheck,
+                   i18n( "Clicking this check box makes KHexEdit forget his recent document list "
+                          "when the program is closed.\n"
+                          "Note: it will not erase any document of the recent document list "
+                          "created by KDE." ) );
   connect( mFile.discardRecentCheck, SIGNAL(toggled(bool)),
     this, SLOT( slotChanged()));
 
   text = i18n("Cl&ear \"Recent\" Document List");
   QPushButton *discardRecentButton = new QPushButton( page );
   discardRecentButton->setText( text );
+  QWhatsThis::add( discardRecentButton,
+                   i18n( "Clicking this button makes KHexEdit forget his recent document list.\n"
+                          "Note: it will not erase any document of the recent document list "
+                          "created by KDE." ) );
   topLayout->addWidget( discardRecentButton, 0, AlignCenter );
   connect( discardRecentButton, SIGNAL(clicked()),
 	   SIGNAL(removeRecentFiles()) );
