@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
 
@@ -41,6 +41,7 @@ class KRadioAction;
 class KSelectAction;
 class KToggleAction;
 class KToolBarButton;
+class KURL;
 class CDragLabel;
 
 
@@ -146,7 +147,6 @@ class KHexEdit : public KMainWindow
     inline void setStartupOffset( uint offset );
 
   public slots:
-    void recentFile( int id );
     KHexEdit *newWindow( void );
     void pasteNewWindow( void );
     void closeWindow( void );
@@ -181,6 +181,11 @@ class KHexEdit : public KMainWindow
     void setEncoding( void );
     void documentMenuCB( int id );
 
+    /**
+     *  Slot for opening a file among the recently opened files.
+     */
+    void slotFileOpenRecent( const KURL & );
+
 protected:
     virtual bool queryExit( void );
     virtual bool queryClose( void );
@@ -190,7 +195,6 @@ protected:
     void removeRecentFiles( void );
     void conversionClosed( void );
     void searchBarClosed( void );
-    void delayedRecentOpen( void );
     void resizeTest();
 
   private:
@@ -208,7 +212,6 @@ protected:
     void renameDocument( const QString &curName, const QString &newName );
     void setTickedDocument( const QString &fileName );
 
-    void makeExitFileList( void );
     void writeConfiguration( KConfig &config );
     void readConfiguration( KConfig &config );
     bool eventFilter( QObject *obj, QEvent *event );
@@ -223,14 +226,9 @@ protected:
     CHexManagerWidget *mManager;
     QStringList mDocumentList;
 
-    QStringList mStartupFileList;   // Files to automatically open on startup
-    QStringList mStartupOffsetList; // Start offset for those files.
-
-    QStringList mExitFileList;      // Stores "Recent" file order on exit.
-    QStringList mExitOffsetList;    // Stores "Recent" file offset on exit.
-
-    QStringList mRecentOffsetList;  // Values read from config. file
-    uint        mStartupOffset;     // Value read from commandline
+    QStringList mStartupFileList;   ///< Files to automatically open on startup
+    QStringList mStartupOffsetList; ///< Start offset for those files.
+    uint mStartupOffset; ///< Value read from the command line
 
     SActionList mAction;
 
