@@ -3,6 +3,7 @@
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  * Copyright (c) 2002 Marc Mutz <mutz@kde.org>
+ * Copyright (c) 2006 Flavio Castelli <flavio.castelli@gmail.com>
  *
  * Requires the Qt widget libraries, available at no cost at
  * http://www.troll.no/
@@ -58,6 +59,7 @@ public:
 private slots:
 
   void configChanged();
+  void runMonitorChanged();
   void slotStartMonitor();
   void iconChanged();
   void BatteryStateUpdate();
@@ -69,9 +71,11 @@ private:
 
         QSpinBox* editPoll;
         QCheckBox* runMonitor;
+        QCheckBox* showLevel;
         QCheckBox* notifyMe;
 	QCheckBox* blankSaver;
         bool            enablemonitor;
+        bool            showlevel;
         bool            enablequitmenu;
 	bool		useblanksaver;
 	bool		notifyme;
