@@ -1,10 +1,11 @@
 /*
  * daemondock.cpp
  * Copyright (C) 1999 Paul Campbell <paul@taniwha.com>
+ * Copyright (C) 2006 Flavio Castelli <flavio.castelli@gmail.com>
  *
  * This file contains the docked widget for the laptop battery monitor
  *
- * $Id: daemondock.cpp 490596 2005-12-22 13:05:45Z scripty $
+ * $Id: daemondock.cpp 721296 2007-10-04 22:53:11Z dfaure $
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,6 +30,7 @@
 #include <klocale.h>
 #include <kpopupmenu.h>
 #include <dcopclient.h>
+#include <dcopref.h>
 #include "kpcmciainfo.h"
 #include "daemondock.h"
 #include "portable.h"
@@ -42,6 +44,8 @@
 #include <qvbox.h>
 #include <qstringlist.h>
 #include <qbitmap.h>
+#include <qpainter.h>
+#include <kiconeffect.h>
 extern void wake_laptop_daemon();
 
 laptop_dock::laptop_dock( laptop_daemon* parent )
@@ -496,9 +500,9 @@ void laptop_dock::invokeHibernation()
 
 void laptop_dock::invokeLockHibernation()
 {
-  DCOPClient* client = kapp->dcopClient();
-  if (client)
-      client->send("kdesktop", "KScreensaverIface", "lock()", "");
+  DCOPRef dr("kdesktop", "KScreensaverIface");
+  DCOPReply reply=dr.call("lock");
+
   laptop_portable::invoke_hibernation();
 }
 void laptop_dock::invokeStandby()
@@ -618,22 +622,20 @@ void laptop_dock::displayPixmap()
 		}
 	}
 quit:
-
-	QPixmap q;
-	q.convertFromImage(image);
-	if (bmmask)
-		q.setMask(*bmmask);
-	setPixmap(q);
-	adjustSize();
-
-	QString tmp;
+        
+        QString tmp;
+        QString levelString;
+        
 	if (!pdaemon->exists()) {
 		tmp = i18n("Laptop power management not available");
+                levelString =  i18n("N/A");
 	} else
 	if (pdaemon->powered) {
 		if (pdaemon->val == 100) {
 			tmp = i18n("Plugged in - fully charged");;
+                        levelString = "100%";
 		} else if (pdaemon->val >= 0) {
+                        levelString.sprintf ("%i%%", pdaemon->val);
 			if (pdaemon->left >= 0) {
 				QString num3;
 				num3.setNum(pdaemon->left%60);
@@ -646,9 +648,11 @@ quit:
 			}
 		} else {
 			tmp = i18n("Plugged in - no battery");
+                        levelString = i18n("N/A");
 		}
 	} else {
 		if (pdaemon->val >= 0) {
+                        levelString.sprintf ("%i%%", pdaemon->val);
 			if (pdaemon->left >= 0) {
 				QString num3;
 				num3.setNum(pdaemon->left%60);
@@ -662,9 +666,90 @@ quit:
 			// running without any power source...
 			// happens eg. due to ACPI not being able to handle battery hot-plugin
 			tmp = i18n("No power source found");
+                        levelString = i18n("N/A");
 		}
 	}
-	QToolTip::add(this, tmp);
+
+    
+        // prepare icon for systemtray
+        
+        KConfig* config =  new KConfig("kcmlaptoprc");
+        bool showlevel = false;
+        
+        if (config)
+        {
+            config->setGroup("BatteryDefault");
+            showlevel= config->readBoolEntry("ShowLevel", false);
+            delete config;
+        }
+        
+        if (showlevel)
+        {
+            // lot of code taken from kmail kmsystemtray class
+            
+            int oldPixmapWidth = image.size().width();
+            int oldPixmapHeight = image.size().height();
+            
+            QFont percentageFont = KGlobalSettings::generalFont();
+            percentageFont.setBold(true);
+        
+            // decrease the size of the font for the number of unread messages if the
+            // number doesn't fit into the available space
+            float percentageFontSize = percentageFont.pointSizeFloat();
+            QFontMetrics qfm( percentageFont );
+            int width = qfm.width( levelString );
+            if( width > oldPixmapWidth )
+            {
+            percentageFontSize *= float( oldPixmapWidth ) / float( width );
+            percentageFont.setPointSizeFloat( percentageFontSize );
+            }
+        
+            // Create an image which represents the number of unread messages
+            // and which has a transparent background.
+            // Unfortunately this required the following twisted code because for some
+            // reason text that is drawn on a transparent pixmap is invisible
+            // (apparently the alpha channel isn't changed when the text is drawn).
+            // Therefore I have to draw the text on a solid background and then remove
+            // the background by making it transparent with QPixmap::setMask. This
+            // involves the slow createHeuristicMask() function (from the API docs:
+            // "This function is slow because it involves transformation to a QImage,
+            // non-trivial computations and a transformation back to a QBitmap."). Then
+            // I have to convert the resulting QPixmap to a QImage in order to overlay
+            // the light KMail icon with the number (because KIconEffect::overlay only
+            // works with QImage). Finally the resulting QImage has to be converted
+            // back to a QPixmap.
+            // That's a lot of work for overlaying the KMail icon with the number of
+            // unread messages, but every other approach I tried failed miserably.
+            //                                                           IK, 2003-09-22
+            QPixmap percentagePixmap( oldPixmapWidth, oldPixmapHeight );
+            percentagePixmap.fill( Qt::white );
+            QPainter p( &percentagePixmap );
+            p.setFont( percentageFont );
+            p.setPen( Qt::black );
+            p.drawText( percentagePixmap.rect(), Qt::AlignCenter, levelString );
+            percentagePixmap.setMask( percentagePixmap.createHeuristicMask() );
+            QImage percentageImage = percentagePixmap.convertToImage();
+        
+            // Overlay the light KMail icon with the number image
+            QImage iconWithPercentageImage = image.copy();
+            KIconEffect::overlay( iconWithPercentageImage, percentageImage );
+        
+            QPixmap iconWithPercentage;
+            iconWithPercentage.convertFromImage( iconWithPercentageImage );
+            
+            setPixmap( iconWithPercentage );
+        }
+        else
+        {
+            QPixmap q;
+            q.convertFromImage(image);
+            if (bmmask)
+                    q.setMask(*bmmask);
+            setPixmap(q);
+        }
+        adjustSize();
+            
+        QToolTip::add(this, tmp);
 }
 
 #include "daemondock.moc"
