@@ -161,6 +161,7 @@ typedef struct cistpl_funcid_t {
 
 typedef struct cistpl_funce_t {
     u_char	type;
+    u_char	data[1];
 } cistpl_funce_t;
 
 /*======================================================================
@@ -225,6 +226,7 @@ typedef struct cistpl_data_serv_t {
     u_char	escape;
     u_char	encrypt;
     u_char	misc_features;
+    u_char	ccitt_code[1];
 } cistpl_data_serv_t;
 
 typedef struct cistpl_fax_serv_t {
@@ -234,6 +236,7 @@ typedef struct cistpl_fax_serv_t {
     u_char	encrypt;
     u_char	features_0;
     u_char	features_1;
+    u_char	ccitt_code[1];
 } cistpl_fax_serv_t;
 
 typedef struct cistpl_voice_serv_t {
