@@ -16,19 +16,21 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _DISPLAYSKIN_H_
 #define _DISPLAYSKIN_H_
 
+#include <kdemacros.h>
+
 #include <qstring.h>
 #include <qpixmap.h>
 
 namespace KMilo {
 
-class DisplaySkin {
+class KDE_EXPORT DisplaySkin {
 	public:
 		DisplaySkin();
 		virtual ~DisplaySkin();
