@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef GENERAL_H
@@ -58,15 +58,12 @@ namespace KSim
       KIntSpinBox *m_sizeHSpin;
       QLabel *m_sizeWLabel;
       KIntSpinBox *m_sizeWSpin;
-      QCheckBox *m_showDock;
-      QCheckBox *m_savePos;
-      QCheckBox *m_stayOnTop;
       QCheckBox *m_displayFqdn;
       QCheckBox *m_recolourThemes;
   };
 
   class ClockPrefs : public QWidget
-  {   
+  {
     Q_OBJECT
     public:
       ClockPrefs(QWidget *parent, const char *name=0);
@@ -78,12 +75,7 @@ namespace KSim
 
     private:
       QVBoxLayout *m_mainLayout;
-      QGroupBox *m_timeBox;
-      QGroupBox *m_dateBox;
-      QVBoxLayout *m_timeLayout;
-      QVBoxLayout *m_dateLayout;
       QCheckBox *m_timeCheck;
-      QCheckBox *m_24hourCheck;
       QCheckBox *m_dateCheck;
   };
 
@@ -120,7 +112,7 @@ namespace KSim
       QIconSet m_addIcon;
       QIconSet m_removeIcon;
   };
-  
+
   class MemoryPrefs : public QWidget
   {
     Q_OBJECT
@@ -156,7 +148,7 @@ namespace KSim
       QIconSet m_addIcon;
       QIconSet m_removeIcon;
   };
-  
+
   class SwapPrefs : public QWidget
   {
     Q_OBJECT
