@@ -14,7 +14,7 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
 #ifndef KSIM__PROGRESS_H
@@ -22,13 +22,15 @@
 
 #include "label.h"
 
+#include <kdemacros.h>
+
 namespace KSim
 {
   /**
    * provides a label with a progress bar meter
    * @author Robbie Ward <linuxphreak@gmx.co.uk>
    */
-  class Progress : public KSim::Label
+  class KDE_EXPORT Progress : public KSim::Label
   {
     Q_OBJECT
     public:
