@@ -41,7 +41,13 @@
 #include <progress.h>
 #include <themetypes.h>
 
-#ifdef Q_OS_FREEBSD
+#if defined(__DragonFly__)
+#include <sys/time.h>
+#include <sys/param.h>
+#include <sys/resource.h>
+#include <devstat.h>
+#include <stdlib.h>
+#elif defined(Q_OS_FREEBSD)
 #include <sys/param.h>
 #if __FreeBSD_version < 500101
 #include <sys/dkstat.h>
@@ -343,7 +349,7 @@ void DiskView::updateData(DiskList &disks)
 #endif
 
 #ifdef Q_OS_FREEBSD
-#if __FreeBSD_version < 500107
+#if defined(__DragonFly__) || __FreeBSD_version < 500107
 #define	devstat_getdevs(fd, stats)	getdevs(stats)
 #define	devstat_selectdevs		selectdevs
 #define	bytes_read(dev)			(dev).bytes_read
