@@ -30,7 +30,7 @@
 #include <sys/types.h>
 #include <sys/param.h>
 
-#ifdef HAVE_SYS_STATVFS_H
+#if defined(HAVE_SYS_STATVFS_H) && !defined(__DragonFly__)
 #include <sys/statvfs.h>
 #elif defined( HAVE_SYS_STATFS_H )
 #include <sys/statfs.h>
@@ -59,10 +59,12 @@
 #include <stdio.h>
 #include <unistd.h>
 
-#ifdef HAVE_STATVFS
+#if defined(HAVE_STATVFS) && !defined(__DragonFly__)
 typedef struct statvfs ksim_statfs;
+#define ksim_getfsstat getvfsstat
 #elif defined( HAVE_STATFS ) || defined( Q_OS_FREEBSD )
 typedef struct statfs ksim_statfs;
+#define ksim_getfsstat getfsstat
 #else
 typedef struct // fall back for (possibly) non-supported systems
 {
@@ -73,7 +75,7 @@ typedef struct // fall back for (possibly) non-supported systems
 
 int fsystemStats( const char * file, ksim_statfs & stats )
 {
-#ifdef HAVE_STATVFS
+#if defined(HAVE_STATVFS) && !defined(__DragonFly__)
   return statvfs( file, &stats );
 #elif defined( HAVE_STATFS ) || defined( Q_OS_FREEBSD )
   return statfs( file, &stats );
@@ -162,9 +164,9 @@ FilesystemStats::List FilesystemStats::readEntries()
 #endif
 
 #ifdef USE_FSSTAT
-  struct statfs sfs[32];
+  ksim_statfs sfs[32];
   int fs_count;
-  if ( ( fs_count = getfsstat( sfs, sizeof( sfs ), 0 ) ) != -1 )
+  if ( ( fs_count = ksim_getfsstat( sfs, sizeof( sfs ), 0 ) ) != -1 )
   {
     for ( int i = 0; i < fs_count; i++ )
     {
