@@ -301,7 +301,7 @@ void KWalletItem::dropped(QDropEvent *e, const QValueList<QIconDragItem>& lst) {
 		//delete the folder from the source if we were moving
 		Qt::ButtonState state = kapp->keyboardMouseState();
 		if (e->source() && e->source()->parent() &&
-			e->source()->parent()->className() == "KWalletEntryList" && 
+			!strcmp(e->source()->parent()->className(), "KWalletEntryList") &&
 			!(state & Qt::ControlButton)) {
 		
 			KWalletEntryList *el =
@@ -390,13 +390,13 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QListViewItem *item) {
 
 	//detect if we are dragging from kwallet itself
 	if (e->source() && e->source()->parent() &&
-		e->source()->parent()->className() == "KWalletEntryList") {
+		!strcmp(e->source()->parent()->className(), "KWalletEntryList")) {
 
 		el = dynamic_cast<KWalletEntryList*>(e->source()->parent());
 		if (!el) {
 			KMessageBox::error(this, i18n("An unexpected error occurred trying to drop the item"));
-		}
-		sel = el->selectedItem();
+		} else
+			sel = el->selectedItem();
 	}
 
 	if (e->provides("application/x-kwallet-entry")) {
