@@ -199,6 +199,7 @@ private:
     bool repaintInProgress;
     //bool reloading;
     bool want_right_button;
+    bool want_meter_wheel_event;
 
     NETWinInfo* info;
     bool onTop;
@@ -290,6 +291,8 @@ public slots:
      */
     void setWantRightButton(bool yesno) { want_right_button = yesno; }
 
+    void setWantMeterWheelEvent(bool yesno) { want_meter_wheel_event = yesno; }
+
     /**
      * can be used to fire up the karamba management popup menu
      */
@@ -297,6 +300,7 @@ public slots:
 
 private:
     bool m_reloading;
+    bool themeStarted;
     QTimer *m_sysTimer;
     int m_interval;
 
